@@ -37,7 +37,7 @@
 # vim: tabstop=4 expandtab shiftwidth=4
 
 
-from datetime import datetime
+import datetime
 
 from pascha.traditions import Western
 
@@ -58,23 +58,12 @@ class Feasts(object):
     >>> f.date_to_feasts(4, 27)
     """
 
-    #
-    tradition = Western()
-
-    #
-    year = datetime.now().year
-
-    # This dictionary contains key, value pairs where a key is a date and its
-    # corresponding value is a list of all of the feasts that fall on that date.
-    date = {}
-
-    # This dictionary contains key, value pairs where a key is a feast name and
-    # its corresponding value is the date on which that feast falls.
-    feasts = {}
-
-    def __init__(self, Tradition=Western, year=datetime.now().year):
+    def __init__(self, Tradition=Western, year=datetime.datetime.now().year):
         """Initialize a Feasts object."""
         self.tradition = Tradition()
+        self.year = datetime.datetime.now().year
+        self.date = {}
+        self.feasts = {}
         self.change_year(year)
 
     def change_year(self, year):
@@ -82,7 +71,7 @@ class Feasts(object):
         self.year = year
         self.date = {}
         self.feasts = {}
-        pascha = self.tradition.compute_pascha(year)
+        pascha = self.tradition.computus(year)
         for feast in self.tradition.offset.keys():
             date = pascha + self.tradition.offset[feast]
             self.date[feast] = date
@@ -97,7 +86,7 @@ class Feasts(object):
 
     def date_to_feasts(self, month, day):
         """Given a date, return a list of all of the feasts that fall on it."""
-        dt = datetime(self.year, month, day)
+        dt = datetime.datetime(self.year, month, day)
         try:
             return self.feasts[dt]
         except KeyError:
